;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "apheleia" "20260619.1935"
  "Reformat buffer stably."
  '((emacs "27"))
  :url "https://github.com/radian-software/apheleia"
  :commit "14a0bb4454fb2cc3b5b377619288b742ce117da5"
  :revdesc "14a0bb4454fb"
  :keywords '("tools")
  :authors '(("Radian LLC" . "contact+apheleia@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+apheleia@radian.codes")))
